package com.lyg.application.entity;

import com.alibaba.excel.annotation.ExcelProperty;
import com.baomidou.mybatisplus.annotation.*;
import com.lyg.common.util.excel.LocalDateConverter;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotBlank;
import java.io.Serializable;
import java.time.LocalDate;
import java.time.LocalDateTime;

/**
 * 轮岗列表;
 *
 * @author : http://www.chiner.pro
 * @date : 2024-3-6
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = false)
@ApiModel(value = "轮岗列表", description = "")
@TableName("ta_rotation")
public class TaRotation implements Serializable, Cloneable {

    @ApiModelProperty(name = "轮岗Id", notes = "")
    @TableId(value = "rotation_id", type = IdType.ASSIGN_UUID)
    private String rotationId;

    @ExcelProperty(index = 0)
    @ApiModelProperty(name = "序号", notes = "")
    private String sort;

    @ExcelProperty(index = 1)
    @NotBlank(message = "总行部门不能为空")
    @ApiModelProperty(name = "总行部门/一级分行", notes = "")
    private String headOfficeOrg;

    @ExcelProperty(index = 2)
    @NotBlank(message = "员工工号不能为空")
    @ApiModelProperty(name = "员工工号", notes = "")
    private String employeeNum;

    @ExcelProperty(index = 3)
    @NotBlank(message = "员工姓名不能为空")
    @ApiModelProperty(name = "员工姓名", notes = "")
    private String employeeName;

    @ExcelProperty(index = 4)
    @NotBlank(message = "单位机构号不能为空")
    @ApiModelProperty(name = "具体单位机构号", notes = "")
    private String specificOrgNum;

    @ExcelProperty(index = 5)
    @NotBlank(message = "所在单位具体名称不能为空")
    @ApiModelProperty(name = "所在单位具体名称", notes = "")
    private String specificOrgName;

    @ExcelProperty(index = 6)
    @ApiModelProperty(name = "对应机构层次", notes = "")
    private String counterInstitutionsLevel;

    @ExcelProperty(index = 7)
    @ApiModelProperty(name = "当前职位", notes = "")
    private String currentPosition;

    @ExcelProperty(index = 8)
    @ApiModelProperty(name = "对应重要岗位", notes = "")
    private String counterImpPositions;

    @ExcelProperty(index = 9)
    @ApiModelProperty(name = "对应总行条线", notes = "")
    private String counterHeadOfficeLine;

    //    @DateTimeFormat("yyyy/MM/dd")
    @ExcelProperty(index = 10, converter = LocalDateConverter.class)
    @ApiModelProperty(name = "从事相应重要岗位时间 格式：年/月/日", notes = "")
    private LocalDate durationOfEmployment;

    @ExcelProperty(index = 11)
    @ApiModelProperty(name = "轮岗周期要求（年）", notes = "")
    private Integer rotationCycle;

    //    @DateTimeFormat("yyyy/MM/dd")
    @ExcelProperty(index = 12, converter = LocalDateConverter.class)
    @ApiModelProperty(name = "轮岗截止日期", notes = "")
    private LocalDate rotationDeadline;

    @ExcelProperty(index = 13)
    @ApiModelProperty(name = "对应轮岗方式", notes = "")
    private String counterRotationMethod;

    @ExcelProperty(index = 14)
    @ApiModelProperty(name = "轮岗后单位机构号", notes = "")
    private String orgNumJobRotation;

    @ExcelProperty(index = 15)
//    @NotBlank(message = "轮岗后单位具体名称不能为空")
    @ApiModelProperty(name = "轮岗后单位具体名称", notes = "")
    private String specificNameOrgRotation;

    @ExcelProperty(index = 16)
    @ApiModelProperty(name = "轮岗后职位", notes = "")
    private String jobRotationPost;

    @ExcelProperty(index = 17)
    @ApiModelProperty(name = "轮岗后对应重要岗位", notes = "")
    private String counterImpPostRotation;

    @ExcelProperty(index = 18)
    @ApiModelProperty(name = "轮岗后对应总行条线", notes = "")
    private String counterOfficeLineRotation;

    //    @DateTimeFormat("yyyy/MM/dd")
    @ExcelProperty(index = 19, converter = LocalDateConverter.class)
    @ApiModelProperty(name = "轮岗执行时间 格式：年/月/日", notes = "")
    private LocalDate rotationExeTime;

    @ExcelProperty(index = 20)
    @ApiModelProperty(name = "备注", notes = "")
    private String remark;

    @ExcelProperty(index = 21)
    @ApiModelProperty(name = "立查立改(是/否）", notes = "")
    private String checkChange;

    @ExcelProperty(index = 22)
    @ApiModelProperty(name = "是否问责", notes = "")
    private String accountability;

    @ExcelProperty(index = 23)
    @ApiModelProperty(name = "事实确认书编号", notes = "")
    private String factConfirmationNum;

    @ExcelProperty(index = 24)
    @ApiModelProperty(name = "自查自纠(是/否）", notes = "")
    private String checkCorrect;

    //    @DateTimeFormat("yyyy/MM/dd")
    @ExcelProperty(index = 25, converter = LocalDateConverter.class)
    @ApiModelProperty(name = "计划轮岗日期", notes = "")
    private LocalDate planRotationDate;


    @ApiModelProperty(name = "状态", notes = "")
    private Integer status;

    @ApiModelProperty(name = "创建人", notes = "")
    @TableField(fill = FieldFill.INSERT)
    private String createUser;

    @ApiModelProperty(name = "创建时间", notes = "")
    @TableField(fill = FieldFill.INSERT)
    private LocalDateTime createDate;

    @ApiModelProperty(name = "更新人", notes = "")
    @TableField(fill = FieldFill.INSERT_UPDATE)
    private String updateUser;

    @ApiModelProperty(name = "更新时间", notes = "")
    @TableField(fill = FieldFill.INSERT_UPDATE)
    private LocalDateTime updateDate;

    @ApiModelProperty(name = "删除标志", notes = "1删除")
    @TableField(fill = FieldFill.INSERT)
    private Integer deleted;

}