package com.lyg.application.service.impl;

import com.lyg.application.entity.TaMandatoryLeave;
import com.lyg.application.mapper.TaMandatoryLeaveMapper;
import com.lyg.application.service.TaMandatoryLeaveService;
import com.lyg.system.mapper.SysPositionMapper;
import com.lyg.system.service.SysOrgService;
import com.lyg.system.service.SysPositionService;
import com.lyg.system.service.impl.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;

/**
 * 强制休假表;(ta_mandatory_leave)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2024-3-6
 */
@Service
public class TaMandatoryLeaveServiceImpl extends BaseServiceImpl<TaMandatoryLeaveMapper, TaMandatoryLeave> implements TaMandatoryLeaveService {
    private final List<String> errorMessages = new ArrayList<>();
    @Autowired
    private SysOrgService sysOrgService;
    @Autowired
    private SysPositionService sysPositionService;
    @Autowired
    private SysPositionMapper sysPositionMapper;

    @Override
    public TaMandatoryLeave handleEntity(TaMandatoryLeave entity, Integer index) throws Exception {
//校验验证
        System.out.println("******************************entity**************************************");
        System.out.println(entity);

        String orgCode = entity.getOrgNum();//单位机构号
        String orgName = entity.getOrgName().replaceAll("\n", "");//单位机构名

        String counterImpPost = null;
        if (entity.getCounterImpPost() != null) {
            counterImpPost = entity.getCounterImpPost().replaceAll("\n", "");//岗位名
            //        轮岗之前岗位名  获取id
            String rotationId = sysPositionMapper.getPostId(counterImpPost);
            entity.setCounterImpPost(rotationId);
        }
        LocalDate durationOfEmployment = entity.getStartTimeVacation();
        LocalDate vacationDeadline = entity.getVacationDeadline();


        Long count = sysOrgService.countBy("org_id", orgCode, true);
        if (count == 0 || orgCode.isEmpty()) {
            errorMessages.add("第 " + index + " 行处理发生错误: " + "没有此机构号 " + orgCode);
        }

        count = sysOrgService.countBy("name", orgName, true);
        if (count == 0 || orgName.isEmpty()) {
            errorMessages.add("第 " + index + " 行处理发生错误: " + "没有此机构名字 " + orgName);
        }

        count = sysPositionService.countBy("name", counterImpPost, true);
        if (count == 0) {
            errorMessages.add("第 " + index + " 行处理发生错误: " + "没有此岗位 " + counterImpPost);
        }

        if (durationOfEmployment == null) {
            errorMessages.add("第 " + index + " 行时间错误:休假起始时间为 " + durationOfEmployment);
        }
        if (vacationDeadline == null) {
            errorMessages.add("第 " + index + " 行时间错误:休假截止时间为 " + vacationDeadline);
        }

        return entity;
    }

    @Override
    public void saveEntityBatch(List<TaMandatoryLeave> entityList) {
        // 实现逻辑：保存批量实体
        System.out.println("******************************entityList**************************************");
        System.out.println(entityList);
        for (TaMandatoryLeave taMandatoryLeave : entityList) {
            baseMapper.insert(taMandatoryLeave);
        }
    }

    public List<String> getErrorMessages() {
        return errorMessages;

    }
}