package com.lyg.common.util.excel;

import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.write.builder.ExcelWriterBuilder;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.lyg.common.util.StringUtil;

import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class ExcelUtil {

    public static void formatResponse(HttpServletResponse response, String fileName) {
        response.setContentType("application/vnd.ms-excel");
        response.setCharacterEncoding("utf-8");
        response.setHeader("Access-Control-Expose-Headers", "Content-Disposition");
        response.setHeader("Content-Disposition", "attachment;filename="+ StringUtil.urlEncode(fileName)+".xlsx");
    }

    /**
     * 发送 excel 到客户端
     * 暂时只支持单 sheet 页
     * @param response
     * @param data
     * @param fileName
     * @throws IOException
     */
    public static void flush(HttpServletResponse response, Class dataClass, List data, String fileName) throws IOException {
        formatResponse(response, fileName);
        EasyExcel.write(response.getOutputStream(), dataClass).sheet("sheet1").doWrite(data);
    }

    public static void flush(HttpServletResponse response, List<List<Map<String, Object>>> data, List<List<String>> customHead, String fileName) throws IOException {
        formatResponse(response, fileName);

        boolean noCustomHeads = null == customHead || customHead.size() == 0;

        List<List<String>> head = new ArrayList<>();
        List<List<Object>> contents = new ArrayList<>();
        if (null != data && data.size() > 0) {
            int row = 0;
            for (List<Map<String, Object>> fields: data) {

                List<Object> item = new ArrayList<>();
                for (Map<String, Object> field: fields) {
                    if (row == 0 && noCustomHeads) {
                        List<String> keys = new ArrayList<>();
                        keys.add(field.get("name").toString());
                        head.add(keys);
                    }

                    item.add(field.get("value"));
                }

                contents.add(item);
                row += 1;
            }
        }

        ExcelWriterBuilder writerBuilder = EasyExcel.write(response.getOutputStream());
        if (noCustomHeads) {
            writerBuilder.head(head);
        } else {
            writerBuilder.head(customHead);
        }

        writerBuilder.registerWriteHandler(new CellWidthWriteHandler())
                .sheet("sheet")
                .registerConverter(new TimestampConverter())
                .registerConverter(new DateConverter())
                .doWrite(contents);
    }
}
