package com.lyg.system.controller;

import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.lyg.system.entity.SysRoleResource;
import com.lyg.framework.log.OpLog;
import com.lyg.system.service.SysRoleResourceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

 /**
 * 角色资源;(sys_role_resource)表控制层
 * @author : http://njyunzhi.com
 * @date : 2023-2-5
 */
@Api(tags = "角色资源对象功能接口")
@RestController
@RequestMapping("/")
public class SysRoleResourceController extends BaseController {

    @Autowired
    public SysRoleResourceService sysRoleResourceService;

//    /**
//     * 通过ID查询单条数据
//     *
//     * @param id 主键
//     * @return 实例对象
//     */
//    @ApiOperation("通过ID查询单条数据")
//    @GetMapping("/sysRoleResource/{id}")
//    public SaResult queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
//        return SaResult.data(sysRoleResourceService.getById(id));
//    }
//
    /**
     * 列表
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "角色资源", action = "查询列表")
    @ApiOperation("列表")
    @GetMapping("/sysRoleResource")
    public SaResult listApp(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                            @ApiParam("角色ID") @RequestParam(value ="roleId") String roleId,
                            @ApiParam("资源类型") @RequestParam(value ="resourceType") String resourceType) throws Exception {

        IPage<SysRoleResource> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<SysRoleResource> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("role_id", roleId);
        queryWrapper.eq("resource_type", resourceType);
        IPage<SysRoleResource> result = sysRoleResourceService.page(pg, queryWrapper);

        return SaResult.data(result);
    }

    /**
     * 新增数据
     *
     * @param roleResourcesList 授权列表
     * @return 实例对象
     */
    @OpLog(module = "角色资源", action = "新增数据")
    @ApiOperation("新增数据")
    @PostMapping("/sysRoleResource")
    public SaResult add(@ApiParam("授权列表") @RequestBody List<SysRoleResource> roleResourcesList,
                        @ApiParam("角色ID") @RequestParam("roleId") String roleId) throws Exception {
        sysRoleResourceService.mergeData(roleId, roleResourcesList);
        return SaResult.data(roleResourcesList);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @OpLog(module = "角色资源", action = "删除数据")
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/sysRoleApp/{id}")
    public SaResult deleteRoleAppById(@ApiParam("对象ID") @PathVariable String id){
        sysRoleResourceService.removeById(id);
        return SaResult.ok("success");
    }
}