package com.lyg.system.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.lyg.common.Constants;
import com.lyg.common.util.StringUtil;
import com.lyg.system.entity.SysOrg;
import com.lyg.system.entity.SysUser;
import com.lyg.system.mapper.SysOrgMapper;
import com.lyg.system.mapper.SysUserMapper;
import com.lyg.system.service.SysOrgService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 机构表;(sys_org)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2023-1-27
 */
@Service
public class SysOrgServiceImpl extends BaseServiceImpl<SysOrgMapper, SysOrg> implements SysOrgService {

    @Autowired
    SysUserMapper sysUserMapper;

    @Override
    public void createNew(SysOrg sysOrg, SysUser user) {
//        long maxCode = getMaxCode(sysOrg.getParentId());
//        sysOrg.setOrgCode(String.valueOf(maxCode + 1));
        sysOrg.setOrgCode(sysOrg.getOrgCode());
        sysOrg.setOrgId(sysOrg.getOrgCode());
        sysOrg.setStatus(Constants.STATUS_NORMAL);
//        sysOrg.setCreateUser(user.getUserId());
//        sysOrg.setCreateDate(LocalDateTime.now());

        save(sysOrg);
    }

    @Override
    public long getMaxCode(String parentId) {
        String maxCode = baseMapper.getMaxCode(parentId);
        if (StringUtil.isEmpty(maxCode)) {
            if (Constants.ROOT_TREE.equals(parentId)) {
                return 100;
            } else {
                SysOrg org = getById(parentId);
                String childCode = org.getOrgCode() + "000";
                return Long.parseLong(childCode);
            }
        }

        return Long.parseLong(maxCode);
    }

    @Override
    public void updateData(SysOrg sysOrg) {

        // 比较是否更新了父节点
        SysOrg origin = getById(sysOrg.getOrgId());
        if (!origin.getParentId().equals(sysOrg.getParentId())) {
            // 如果更换了
            long maxCode = getMaxCode(sysOrg.getParentId());
            String newCode = String.valueOf(maxCode + 1);
            // 当前节点以及子节点，全部更换
            baseMapper.changeOrgCode(origin.getOrgCode(), newCode);
            sysOrg.setOrgCode(newCode);
        }

        updateById(sysOrg);
    }

    @Override
    public List<String> getOrgIdByUser(String userId) {
        SysUser sysUser = sysUserMapper.selectById(userId);
        if (null == sysUser || Constants.STATUS_DELETE == sysUser.getStatus()) {
            return new ArrayList<>();
        }

        List<SysOrg> orgList = null;
        if (Constants.ROOT_ORG.equals(sysUser.getOrgId())) {
            // 顶级机构的人可以管理所有
            QueryWrapper<SysOrg> queryWrapper = new QueryWrapper<>();
            queryWrapper.gt("status", Constants.STATUS_DELETE);
            orgList = list(queryWrapper);
        } else {
            orgList = baseMapper.getListByUser(userId);
        }

        return null == orgList
                ? new ArrayList<>()
                : orgList.stream().map(SysOrg::getOrgId).collect(Collectors.toList());
    }

}