package com.lyg.system.service.request;

import cn.dev33.satoken.stp.StpUtil;
import cn.dev33.satoken.util.SaResult;
import cn.hutool.core.lang.TypeReference;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.dtflys.forest.Forest;
import com.dtflys.forest.http.ForestRequest;
import com.dtflys.forest.http.ForestRequestType;
import com.lyg.common.util.StringUtil;
import lombok.Data;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Locale;
import java.util.Map;

@Component
public class Fetch {

    @Value("${yz.sso.host}")
    String host;

    @Value("${yz.sso.port}")
    Integer port;

    private ForestRequest<?> build() {
        ForestRequest<?> request = Forest.request();
        request.setAddress(host, port);

        String token = StpUtil.getTokenValue();
        if (!StringUtil.isEmpty(token)) {
            request.addHeader("Authorization", token);
        }

        return request;
    }

    public Result get(String url, Map<String, Object> params) {
        ForestRequest<?> request = build();
        request.setUrl(url);

        if (null != params) {
            request.addQuery(params);
        }

        Result result = new Result();
        result.setRequest(request);

        return result;
    }

    public Result request(String method, String url, Object data, Map<String, Object> params) {
        ForestRequest<?> request = build();
        request.setUrl(url);
        request.setType(ForestRequestType.findType(method.toUpperCase(Locale.ROOT)));
        request.addHeader("Content-Type", "application/json");

        if (null != params) {
            request.addQuery(params);
        }

        if (null != data) {
            request.addBody(data);
        }

        Result result = new Result();
        result.setRequest(request);

        return result;
    }

    public Result put(String url, Object data, Map<String, Object> params) {
        return request("PUT", url, data, params);
    }
    public Result post(String url, Object data, Map<String, Object> params) {
        return request("POST", url, data, params);
    }

    @Data
    public static class Result {
        ForestRequest<?> request;

        public String exec() throws Exception {
            String resStr = request.execute(String.class);
            if (null == resStr || "".equals(resStr)) {
                throw  new Exception("网络错误");
            }

            JSONObject result = JSONUtil.parseObj(resStr);

            if (200 != result.getInt("code")) {
                throw new Exception(result.getStr("msg"));
            }

            return result.getStr("data");
        }

        public SaResult result() throws Exception {
            SaResult result = request.execute(SaResult.class);
            if (null == result) {
                throw  new Exception("网络错误");
            }

            if (200 != result.getCode()) {
                throw new Exception(result.getMsg());
            }

            return result;
        }

        public <T> T data(Class<T> beanClass) throws Exception {
            String result = exec();

            return JSONUtil.toBean(result, beanClass);
        }

        public <T> T data(TypeReference<T> typeReference) throws Exception {
            String result = exec();

            return JSONUtil.toBean(result, typeReference, true);
        }


        public <T> List<T> list(Class<T> itemClass) throws Exception {
            String result = exec();

            return JSONUtil.toList(result, itemClass);
        }
    }
}
